@@ -3,11 +3,6 @@
 magrittr::`%>%`
 
 
-#' @importFrom tibble glimpse
-#' @export
-tibble::glimpse
-
-
 #' @importFrom dplyr quos select
 get_dot_data <- function(x, qs) {
   if (sjmisc::is_empty(qs))
@@ -15,3 +10,10 @@ get_dot_data <- function(x, qs) {
   else
     suppressMessages(dplyr::select(x, !!!qs))
 }
+
+
+data_frame <- function(...) {
+  x <- data.frame(..., stringsAsFactors = FALSE)
+  rownames(x) <- NULL
+  x
+}
